@@ -23,7 +23,10 @@ def color(S):
     return graph[S].colorIni.color()
 
 def algo(A,B,G):
-    C1, T1 = calc(A,B,G)
+    try:
+        C1, T1 = calc(A,B,G)
+    except IndexError:
+        return [], -1
 
     if T1 - int(T1) == 0:
         C2, T2 = calc(B,A,G)
