@@ -1,8 +1,9 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-import sys
+import sys, locale
 from PyQt4 import QtGui
+from PyQt4 import QtCore
 import graphe
 
 #if __name__ == "__main__":
@@ -18,6 +19,9 @@ import graphe
 if __name__ == "__main__":
     app = QtGui.QApplication (sys.argv)
 
+    translator = QtCore.QTranslator(app)
+    translator.load("/opt/rtap/locale/rtap_" + locale.getlocale()[0] + ".qm")
+    app.installTranslator(translator)
     ui = graphe.Ui_MainWindow()
     ui.setupUi(app)
     ui.show()
